==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/it_IT.php <==
<?php
$lang['friendlyname'] = 'Modulo WYSIWYG TinyMCE';
$lang['uninstalled'] = 'Modulo disinstallato.';
$lang['installed'] = 'Versione installata del modulo %s';
$lang['stripbackgroundtags'] = 'Togli i tags background da CSS';
$lang['source_formatting_text'] = 'Applica la formattazione del sorgente al HTML di uscita';
$lang['dropdownblockformats_text'] = 'Formati nel menu a tendina';
$lang['allowtables'] = 'Permettete operazioni sulle tabelle';
$lang['newlinestyle_text'] = 'Stile di un Invio';
$lang['pstyle'] = 'stile p';
$lang['brstyle'] = 'stile br';
$lang['usecompressiontext'] = 'Usa la compressione gz';
$lang['usecompressionhelp'] = 'Questo pu&ograve; velocizzare il caricamento di TinyMCE, ma pu&ograve; anche prevenire il caricamento su altri sistemi. Usate con cautela.';
$lang['forcedrootblocktext'] = 'Forza il tag p iniziale/finale nel blocco';
$lang['forcedrootblockhelp'] = 'Forza il contenuto ritornato ad almeno essere chiuso in un tag p';
$lang['filepickerstyle'] = 'Stile del Filepicker';
$lang['filepickersize'] = 'Dimensione del Filepicker';
$lang['allowuploadtext'] = 'Permette l&#039;upload e la creazione delle directory in FilePicker';
$lang['cannotreadconfig'] = 'Non posso leggere il file tinyconfig.php direttamente cos&igrave; che TinyMCE probabilmente non funziona. Dovreste controllare i permessi del file e le directory superiori, i quali dovrebbero essere leggibili per tutti ma scrivibile solo per il proprietario.';
$lang['filenameonly'] = 'Mostra nomifile';
$lang['thumbnailsonly'] = 'Mostra miniature';
$lang['filenameandthumbnails'] = 'Mostra entrambi nomifile e miniature';
$lang['skinstext'] = 'Skin';
$lang['skinvariationtext'] = 'Cambio Skin';
$lang['advancedwarning'] = '<strong>Nota bene!<br/>Cambiare queste configurazioni pu&ograve; causare lo stop di TinyMCE o generare codice errato. Modificare solo se conoscete quello che state facendo! Si prega di consultare il sito di TinyMCE prima di giocare con questo.</strong>';
$lang['entityencoding_text'] = 'Encoding delle entit&agrave;';
$lang['rawencoding'] = 'Raw encoding (pi&ugrave; veloce, lavora nella maggiornza dei casi)';
$lang['namedencoding'] = 'Encoding nominativo (come &amp;nbsp ;)';
$lang['numericencoding'] = 'Encoding numerico (come &amp;#160 ;)';
$lang['show_path_text'] = 'Mostra il percorso dell&#039;elemento sotto all&#039;editor.';
$lang['toolbar_tab'] = 'Barra degli Strumenti';
$lang['toolbar_help'] = 'Queste opzioni dovrebbero contenere una lista di nomi di pulsanti/controlli separati da un punto e virgola, da inserire nella barra degli strumenti.';
$lang['toolbar_text'] = 'Barra degli Strumenti';
$lang['toolbarhelptext'] = 'Click qua per vedere le istruzioni di toolbar in TinyMCE-wiki.';
$lang['editor_width_text'] = 'Larghezza del campo di modifica';
$lang['editor_height_text'] = 'Altezza del campo di modifica';
$lang['auto'] = 'Automatico';
$lang['or'] = 'o';
$lang['datetimeformat_text'] = 'Formato Data/Tempo';
$lang['timetext'] = 'Tempo';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Click qua per aiuto su come formattare la data/tempo';
$lang['extraconfigtext'] = 'Configurazione Extra';
$lang['extraconfighelp'] = 'Controlla il TinyMCE-wiki per le istruzioni';
$lang['customdropdowntext'] = 'Tendina personale';
$lang['customdropdownhelp'] = 'Inserisce snippets di codice/testo personalizzabile selezionado in una tendina. 
Un uso banale &egrave; un facile accesso a plugins etc. Il menu &egrave; inserito nella toolbar usando la &#039;Tendina personale&#039;.';
$lang['startenabledtext'] = 'Caricamento dell&#039;editor abilitato';
$lang['startenabledhelp'] = 'Spuntando questo il Tiny-editors &egrave; nello stato di disabilitato. Dovrebbe essere usato con il bottone di scambio.';
$lang['loadcmslinkertext'] = 'Carica il CMSmslinker';
$lang['loadcmslinkerhelp'] = 'Questo genera il codice javascript necessario per permettere al cmsmslinker di essere aggiunto alla toolbar.';
$lang['cmslinkerstyletext'] = 'Stile dei link per CMS-linker';
$lang['cmsselflinkstyle'] = 'Stile {cms_selflink} (supporta pretty urls)';
$lang['ahrefstyle'] = 'Stile a-href (non supporta pretty urls)';
$lang['relativeurlstext'] = 'Genera URL relativi';
$lang['forcecleanpastetext'] = 'Forza la pulizia del codice sull&#039;incolla';
$lang['forcecleanpastehelp'] = 'Questo dovrebbe essere abilitato per rimuovere lo strano codice di formattazione quando si incolla da MS Word';
$lang['bodycss_text'] = 'Foglio di Stile (CSS) del tag Body';
$lang['bodycss_help'] = 'Sar&agrave; aggiunto alla definizione dello Stile CSS del body';
$lang['includeonlyscreencss_text'] = 'Include solo gli Stili CSS di tipo screen';
$lang['includeonlyscreencss_help'] = 'Selezionando questo si permette di attaccare Stili CSS, con il mediatype di tipo screen selezionato, negli Stili di TinyMCE.';
$lang['usestaticconfigtext'] = 'Usa file config statico';
$lang['usestaticconfighelp'] = 'Questo pu&ograve; aiutare a far funzionare tiny su sistemi dove le utility aggiunte a tutte le uscite, come le statistiche degli hosting, fermano i javascript del config file creati dinamicamente';
$lang['usestaticconfigwarning'] = 'Attenzione! Voi avete abilitato l&#039;opzione di un config file statico ma la Vostra directory tmp/  non &egrave; scrivibile. Questo previene il modulo da salvare il file config statico e molto probabilmente render&agrave; inoperativo TinyMCE.';
$lang['showtogglebutton_text'] = 'Mostra bottone per scambiare il WYSIWYG on/off';
$lang['togglewysiwyg'] = 'Scambia WYSIWYG on/off';
$lang['styles_tab'] = 'Stili CSS';
$lang['styles_help'] = 'Se lasciate il primo campo vuoto, TinyMCE esaminer&agrave; il vostro Foglio di Stile ed elencher&agrave; all&#039;utente gli stili contenuti.
Se volete che vengano visualizzati all&#039;utente solo alcuni stili, specificateli nella forma &quot;MioStile1=style1; MioStile2=style2&quot; nel primo campo sotto.
Nota bene: MioStile1=style1 significa UnVostroNomedelloStileCSS = NomeVEROdelloStileCSS.
Nei campi rimanenti potete specificare stili CSS per Tabelle, Righe e Celle che vengono utilizzate nelle caselle corrispondenti. 
Per i campi vuoti verranno utilizzati gli stili generici.';
$lang['css_styles_text'] = 'Stili';
$lang['accessdenied'] = 'Accesso Negato. Si prega di controllare i vostri permessi.';
$lang['error'] = 'Errore!';
$lang['submit'] = 'Inserisci';
$lang['update'] = 'Aggiorna';
$lang['settings'] = 'Impostazioni';
$lang['settingssaved'] = 'Le impostazioni sono state salvate';
$lang['advancedsaved'] = 'Configurazioni avanzate salvate';
$lang['toolbarsaved'] = 'Toolbar salvata';
$lang['stylessaved'] = 'Stili salvati';
$lang['testareatext'] = 'Area di test, nessun contenuto verr&agrave; modificato facendo prove qui...';
$lang['reset'] = 'Riporta ai valori predefiniti';
$lang['resetall'] = 'Riporta tutti i valori a quelli predefiniti';
$lang['confirmreset'] = 'Siete sicuri di voler riportare queste configurazioni ai valori predefiniti?';
$lang['confirmresetall'] = 'Siete sicuri di voler riportare TUTTE le configurazioni ai valori predefiniti?';
$lang['settingsreset'] = 'Queste configurazioni sono state riportate ai predefiniti';
$lang['allsettingsreset'] = 'Tutte le configurazioni sono state riportate ai predefiniti';
$lang['upgraded'] = '&egrave; stata aggiornata alla versione %s';
$lang['customdropdown'] = 'Tendina personale-menu';
$lang['cmsmslinker'] = 'Inserisce un link alle pagine cmsms';
$lang['backend_toolbars'] = 'Configurazioni toolbar per la parte admin';
$lang['frontend_toolbars'] = 'Configurazioni toolbar per il frontend';
$lang['plugins_tab'] = 'Plugins';
$lang['plugins_help'] = 'Scegliete i plugins che volete attivare. Documentazione pu&ograve; essere trovata <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">qua</a>';
$lang['plugins_text'] = 'Plugins';
$lang['saveplugins'] = 'Salva plugins';
$lang['pluginssaved'] = 'Plugins salvati';
$lang['youareintext'] = 'Voi siete qui';
$lang['extrastylestext'] = 'Aggiunge agli Stili CSS';
$lang['extrastyleshelp'] = 'Stili CSS inseriti qui saranno aggiunti agli Stili CSS letti da TinyMCE dopo quelli ricevuti da CMSms';
$lang['uploadnewfile'] = 'Nuovo file';
$lang['uploadfile'] = 'Upload';
$lang['createnewdir'] = 'Nuova directory';
$lang['createdir'] = 'Crea';
$lang['nodirname'] = 'Nessun nome di directory inserito';
$lang['direxists'] = 'Il nome della directory esiste sempre';
$lang['newdircreated'] = 'Nuova directory creata con successo';
$lang['newdirfailed'] = 'Un errore &egrave; successo nella creazione della directory';
$lang['nofile'] = 'Nessun file spedito';
$lang['filetoobig'] = 'Upload di un file troppo grande';
$lang['uploadfailed'] = 'Errore nel muovi del file spedito';
$lang['fileuploaded'] = 'File spedito con successo';
$lang['filepickertitle'] = 'Selezione File';
$lang['success'] = 'Successo';
$lang['fileoperations'] = 'Operazioni sui File';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Dimensione';
$lang['dimensions'] = 'AltezzaxLarghezza';
$lang['advanced_tab'] = 'Avanzate';
$lang['help'] = '	<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>';
$lang['utmz'] = '156861353.1228168733.609.121.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utma'] = '156861353.1807151640.1182960456.1227740242.1228168733.609';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/TinyMCE/lang/ext/it_IT.php <==
<?php
$lang['friendlyname'] = 'Modulo WYSIWYG TinyMCE';
$lang['uninstalled'] = 'Modulo disinstallato.';
$lang['installed'] = 'Versione installata del modulo %s';
$lang['stripbackgroundtags'] = 'Togli i tags background da CSS';
$lang['stiptags_help'] = 'Queste opzioni provano a rimuovere il tipo background dagli Stili CSS.';
$lang['source_formatting_text'] = 'Applica la formattazione del sorgente al HTML di uscita';
$lang['dropdownblockformats_text'] = 'Formati nel menu a tendina';
$lang['allowtables'] = 'Permettete operazioni sulle tabelle';
$lang['newlinestyle_text'] = 'Stile di un Invio';
$lang['pstyle'] = 'stile p';
$lang['brstyle'] = 'stile br';
$lang['usecompressiontext'] = 'Usa la compressione gz';
$lang['usecompressionhelp'] = 'Questo pu&ograve; velocizzare il caricamento di TinyMCE, ma pu&ograve; anche prevenire il caricamento su altri sistemi. Usate con cautela.';
$lang['forcedrootblocktext'] = 'Forza il tag p iniziale/finale nel blocco';
$lang['forcedrootblockhelp'] = 'Forza il contenuto ritornato ad almeno essere chiuso in un tag p';
$lang['filepickerstyle'] = 'Stile del Filepicker';
$lang['filepickersize'] = 'Dimensione del Filepicker';
$lang['allowuploadtext'] = 'Permette l&#039;upload e la creazione delle directory in FilePicker';
$lang['allowscalingtext'] = 'Permette il ridimensionamento al volo dei file spediti';
$lang['scalingdimensionstext'] = 'Dimensioni predefinite';
$lang['resizeto'] = 'Ridimensiona a:';
$lang['useadvancedprofile'] = 'Usa il profilo TinyMCE avanzato';
$lang['saveprofile'] = 'Salva il profilo';
$lang['profilesaved'] = 'Il profilo &egrave; stato salvato';
$lang['profiles_tab'] = 'Profili';
$lang['advanced_backend_toolbars'] = 'Profili di configurazione avanzati per il pannello';
$lang['savestyles'] = 'Salva gli Stili';
$lang['allowadvancedprofile'] = 'Permetti l&#039;uso di profili avanzati in TinyMCE';
$lang['showfilemanagement'] = 'Mostra opzioni di gestione file';
$lang['showfilemanagementhelp'] = 'Mostra gestione di file in opzioni come upload, crea cartelle e cancellazione file in FilePicker, se all&#039;utente &egrave; permesso questo.';
$lang['deleteconfirmation'] = 'Siete sicuri di voler cancellare questo file?';
$lang['deletefilesuccess'] = '&egrave; stato cancellato con successo';
$lang['deletefilefila'] = 'non pu&ograve; essere cancellato';
$lang['cannotreadconfig'] = 'Non posso leggere il file tinyconfig.php direttamente cos&igrave; che TinyMCE probabilmente non funziona. Dovreste controllare i permessi del file e le directory superiori, i quali dovrebbero essere leggibili per tutti ma scrivibile solo per il proprietario.';
$lang['filenameonly'] = 'Mostra nomifile';
$lang['thumbnailsonly'] = 'Mostra miniature';
$lang['showthumbnailfilestext'] = 'Mostra i file miniatura nella lista';
$lang['filenameandthumbnails'] = 'Mostra entrambi nomifile e miniature';
$lang['skinstext'] = 'Skin';
$lang['skinvariationtext'] = 'Cambio Skin';
$lang['advancedwarning'] = '<strong>Nota bene!<br/>Cambiare queste configurazioni pu&ograve; causare lo stop di TinyMCE o generare codice errato. Modificare solo se conoscete quello che state facendo! Si prega di consultare il sito di TinyMCE prima di giocare con questo.</strong>';
$lang['entityencoding_text'] = 'Encoding delle entit&agrave;';
$lang['rawencoding'] = 'Raw encoding (pi&ugrave; veloce, lavora nella maggiornza dei casi)';
$lang['namedencoding'] = 'Encoding nominativo (come &amp;nbsp ;)';
$lang['numericencoding'] = 'Encoding numerico (come &amp;#160 ;)';
$lang['show_path_text'] = 'Mostra il percorso dell&#039;elemento sotto all&#039;editor.';
$lang['toolbar_tab'] = 'Barra degli Strumenti';
$lang['toolbar_help'] = 'Queste opzioni dovrebbero contenere una lista di nomi di pulsanti/controlli separati da virgola, da inserire nella barra degli strumenti. Il carattere | pu&ograve; essere usato invece della parola &#039;separator&#039;';
$lang['toolbar_text'] = 'Barra degli Strumenti';
$lang['toolbarhelptext'] = 'Click qua per vedere le istruzioni di toolbar in TinyMCE-wiki.';
$lang['editor_width_text'] = 'Larghezza del campo di modifica';
$lang['editor_height_text'] = 'Altezza del campo di modifica';
$lang['auto'] = 'Automatico';
$lang['or'] = 'o';
$lang['datetimeformat_text'] = 'Formato Data/Tempo';
$lang['timetext'] = 'Tempo';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Click qua per aiuto su come formattare la data/tempo';
$lang['extraconfigtext'] = 'Configurazione Extra';
$lang['extraconfighelp'] = 'Controlla il TinyMCE-wiki per le istruzioni';
$lang['customdropdowntext'] = 'Tendina personale';
$lang['customdropdownhelp'] = 'Inserisce snippets di codice/testo personalizzabile selezionado in una tendina. 
Un uso banale &egrave; un facile accesso a plugins etc. Il menu &egrave; inserito nella toolbar usando la &#039;Tendina personale&#039;.';
$lang['startenabledtext'] = 'Caricamento dell&#039;editor abilitato';
$lang['startenabledhelp'] = 'Spuntando questo il Tiny-editors &egrave; nello stato di disabilitato. Dovrebbe essere usato con il bottone di scambio.';
$lang['loadcmslinkertext'] = 'Carica il CMSmslinker';
$lang['loadcmslinkerhelp'] = 'Questo genera il codice javascript necessario per permettere al cmsmslinker di essere aggiunto alla toolbar.';
$lang['cmslinkerstyletext'] = 'Stile dei link per CMS-linker';
$lang['cmsselflinkstyle'] = 'Stile {cms_selflink} (supporta pretty urls)';
$lang['ahrefstyle'] = 'Stile a-href (non supporta pretty urls)';
$lang['relativeurlstext'] = 'Genera URL relativi';
$lang['forcecleanpastetext'] = 'Forza la pulizia del codice sull&#039;incolla';
$lang['forcecleanpastehelp'] = 'Questo dovrebbe essere abilitato per rimuovere lo strano codice di formattazione quando si incolla da MS Word';
$lang['bodycss_text'] = 'Foglio di Stile (CSS) del tag Body';
$lang['bodycss_help'] = 'Sar&agrave; aggiunto alla definizione dello Stile CSS del body';
$lang['includeonlyscreencss_text'] = 'Include solo gli Stili CSS di tipo screen';
$lang['includeonlyscreencss_help'] = 'Selezionando questo si permette di attaccare Stili CSS, con il mediatype di tipo screen selezionato, negli Stili di TinyMCE.';
$lang['usestaticconfigtext'] = 'Usa file config statico';
$lang['usestaticconfighelp'] = 'Questo pu&ograve; aiutare a far funzionare tiny su sistemi dove le utility aggiunte a tutte le uscite, come le statistiche degli hosting, fermano i javascript del config file creati dinamicamente';
$lang['usestaticconfigwarning'] = 'Attenzione! Voi avete abilitato l&#039;opzione di un config file statico ma la Vostra directory tmp/  non &egrave; scrivibile. Questo previene il modulo da salvare il file config statico e molto probabilmente render&agrave; inoperativo TinyMCE.';
$lang['showtogglebutton_text'] = 'Mostra bottone per scambiare il WYSIWYG on/off';
$lang['togglewysiwyg'] = 'Scambia WYSIWYG on/off';
$lang['styles_tab'] = 'Stili CSS';
$lang['styles_help'] = 'Se lasciate il primo campo vuoto, TinyMCE esaminer&agrave; il vostro Foglio di Stile ed elencher&agrave; all&#039;utente gli stili contenuti.
Se volete che vengano visualizzati all&#039;utente solo alcuni stili, specificateli nella forma &quot;MioStile1=style1; MioStile2=style2&quot; nel primo campo sotto.
Nota bene: MioStile1=style1 significa UnVostroNomedelloStileCSS = NomeVEROdelloStileCSS.
Nei campi rimanenti potete specificare stili CSS per Tabelle, Righe e Celle che vengono utilizzate nelle caselle corrispondenti. 
Per i campi vuoti verranno utilizzati gli stili generici.';
$lang['css_styles_text'] = 'Stili';
$lang['accessdenied'] = 'Accesso Negato. Si prega di controllare i vostri permessi.';
$lang['error'] = 'Errore!';
$lang['submit'] = 'Inserisci';
$lang['update'] = 'Aggiorna';
$lang['savesettings'] = 'Salva configurazioni';
$lang['settings'] = 'Impostazioni';
$lang['settingssaved'] = 'Le impostazioni sono state salvate';
$lang['saveadvanced'] = 'Salva configurazioni avanzate';
$lang['advancedsaved'] = 'Configurazioni avanzate salvate';
$lang['toolbarsaved'] = 'Toolbar salvata';
$lang['stylessaved'] = 'Stili salvati';
$lang['testareatext'] = '<p>Area di test, nessun contenuto verr&agrave; modificato facendo prove qui...</p>';
$lang['reset'] = 'Riporta ai valori predefiniti';
$lang['resetall'] = 'Riporta tutti i valori a quelli predefiniti';
$lang['confirmreset'] = 'Siete sicuri di voler riportare queste configurazioni ai valori predefiniti?';
$lang['confirmresetall'] = 'Siete sicuri di voler riportare TUTTE le configurazioni ai valori predefiniti?';
$lang['settingsreset'] = 'Queste configurazioni sono state riportate ai predefiniti';
$lang['allsettingsreset'] = 'Tutte le configurazioni sono state riportate ai predefiniti';
$lang['upgraded'] = '&egrave; stata aggiornata alla versione %s';
$lang['customdropdown'] = 'Tendina personale-menu';
$lang['cmsmslinker'] = 'Inserisce un link alle pagine cmsms';
$lang['backend_toolbars'] = 'Configurazioni toolbar per la parte admin';
$lang['frontend_toolbars'] = 'Configurazioni toolbar per il frontend';
$lang['plugins_tab'] = 'Plugins';
$lang['plugins_help'] = 'Scegliete i plugins che volete attivare. Documentazione pu&ograve; essere trovata <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">qua</a>';
$lang['plugins_text'] = 'Plugins';
$lang['saveplugins'] = 'Salva plugins';
$lang['pluginssaved'] = 'Plugins salvati';
$lang['youareintext'] = 'Voi siete qui';
$lang['loadstylesheettext'] = 'Carica gli Stili CSS del contenuto (raccomandato)';
$lang['extrastylestext'] = 'Aggiunge agli Stili CSS';
$lang['extrastyleshelp'] = 'Stili CSS inseriti qui saranno aggiunti agli Stili CSS letti da TinyMCE dopo quelli ricevuti da CMSms';
$lang['uploadnewfile'] = 'Nuovo file';
$lang['uploadfile'] = 'Upload';
$lang['createnewdir'] = 'Nuova directory';
$lang['createdir'] = 'Crea';
$lang['nodirname'] = 'Nessun nome di directory inserito';
$lang['direxists'] = 'Il nome della directory esiste sempre';
$lang['newdircreated'] = 'Nuova directory creata con successo';
$lang['newdirfailed'] = 'Un errore &egrave; successo nella creazione della directory';
$lang['nofile'] = 'Nessun file spedito';
$lang['filetoobig'] = 'Upload di un file troppo grande';
$lang['uploadfailed'] = 'Errore nel muovi del file spedito';
$lang['fileuploaded'] = 'File spedito con successo';
$lang['filepickertitle'] = 'Selezione File';
$lang['success'] = 'Successo';
$lang['fileoperations'] = 'Operazioni sui File';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Dimensione';
$lang['dimensions'] = 'AltezzaxLarghezza';
$lang['advanced_tab'] = 'Avanzate';
$lang['help'] = '	<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>';
$lang['utma'] = '156861353.880130626.1236353467.1242837027.1242854657.40';
$lang['utmz'] = '156861353.1242854657.40.35.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
